aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/definitions/wellknown/identity_server.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/csapi/definitions/wellknown/identity_server.h')
-rw-r--r--lib/csapi/definitions/wellknown/identity_server.h30
1 files changed, 16 insertions, 14 deletions
diff --git a/lib/csapi/definitions/wellknown/identity_server.h b/lib/csapi/definitions/wellknown/identity_server.h
index 67d8b08d..b4304ef7 100644
--- a/lib/csapi/definitions/wellknown/identity_server.h
+++ b/lib/csapi/definitions/wellknown/identity_server.h
@@ -6,21 +6,23 @@
#include "converters.h"
+namespace Quotient
+{
+
+// Data structures
-namespace QMatrixClient
+/// Used by clients to discover identity server information.
+struct IdentityServerInformation
{
- // Data structures
+ /// The base URL for the identity server for client-server connections.
+ QString baseUrl;
+};
- /// Used by clients to discover identity server information.
- struct IdentityServerInformation
- {
- /// The base URL for the identity server for client-server connections.
- QString baseUrl;
- };
- template <> struct JsonObjectConverter<IdentityServerInformation>
- {
- static void dumpTo(QJsonObject& jo, const IdentityServerInformation& pod);
- static void fillFrom(const QJsonObject& jo, IdentityServerInformation& pod);
- };
+template <>
+struct JsonObjectConverter<IdentityServerInformation>
+{
+ static void dumpTo(QJsonObject& jo, const IdentityServerInformation& pod);
+ static void fillFrom(const QJsonObject& jo, IdentityServerInformation& pod);
+};
-} // namespace QMatrixClient
+} // namespace Quotient